@@ -373,4 +373,11 @@ sub standin_discard {
 
 ###############################################################################
 ###############################################################################
+
+=head1 AUTHOR
+
+Kevin Cody-Little <kcody@cpan.org>
+
+=cut
+
 1;
