@@ -166,4 +166,11 @@ sub SCALAR {
 }
 
 
+
+=head1 AUTHOR
+
+Kevin Cody-Little <kcody@cpan.org>
+
+=cut
+
 1;
